@@ -2,9 +2,11 @@ from abc import abstractmethod
 import copy
 import subprocess
 import sys
+from typing import Callable
 
-from adam.config import Config
+from adam.commands.command_helpers import ClusterCommandHelper
 from adam.repl_state import ReplState, RequiredState
+from adam.utils import lines_to_tabular, log, log2
 
 repl_cmds: list['Command'] = []
 
@@ -22,7 +24,6 @@ class Command:
     # Do not do child of child!!!
     @abstractmethod
     def run(self, cmd: str, state: ReplState):
-        Config().debug(cmd)
         if self._successor:
             return self._successor.run(cmd, state)
 
@@ -42,9 +43,8 @@ class Command:
     def validate_state(self, state: ReplState, pg_required: RequiredState = None, app_required: RequiredState = None):
         return state.validate(self.required(), pg_required=pg_required, app_required=app_required)
 
-    @abstractmethod
-    def help(self, state: ReplState) -> str:
-        pass
+    def help(self, _: ReplState) -> str:
+        return None
 
     def args(self, cmd: str):
         a = list(filter(None, cmd.split(' ')))
@@ -103,4 +103,30 @@ class Command:
         while s := cmd._successor:
             print(f'-> {s.command()}', end = '')
             cmd = s
-        print()
\ No newline at end of file
+        print()
+
+    def intermediate_run(self, cmd: str, state: ReplState, args: list[str], cmds: list['Command'], separator='\t'):
+        state, _ = self.apply_state(args, state)
+
+        if state.in_repl:
+            log(lines_to_tabular([c.help(state) for c in cmds], separator=separator))
+
+            return 'command-missing'
+        else:
+            # head with the Chain of Responsibility pattern
+            cmds = Command.chain(cmds)
+            if not cmds.run(cmd, state):
+                log2('* Command is missing.')
+                Command.display_help()
+
+        return state
+
+    def intermediate_help(super_help: str, cmd: str, cmd_list: list['Command'], separator='\t', show_cluster_help=False):
+        log(super_help)
+        log()
+        log('Sub-Commands:')
+
+        log(lines_to_tabular([c.help(ReplState()).replace(f'{cmd} ', '  ', 1) for c in cmd_list], separator=separator))
+        if show_cluster_help:
+            log()
+            ClusterCommandHelper.cluster_help()
\ No newline at end of file
