@@ -17,6 +17,7 @@ class Config:
 
     def __init__(self, path: str = None, is_user_entry = False):
         if path:
+            self.wait_log_flag = False
             try:
                 with open(path) as f:
                     self.params = cast(dict[str, any], yaml.safe_load(f))
@@ -37,7 +38,7 @@ class Config:
         return get_deep_keys(self.params)
 
     def is_debug(self):
-        return Config().get('debug.show-out', False)
+        return Config().get('debug', False)
 
     def debug(self, s: None):
         if self.is_debug():
@@ -83,4 +84,12 @@ class Config:
             log2(f'incorrect path: {key}')
             return None
 
-        return v if v else 'false'
\ No newline at end of file
+        return v if v else 'false'
+
+    def wait_log(self, msg: str):
+        if not self.wait_log_flag:
+            log2(msg)
+            self.wait_log_flag = True
+
+    def clear_wait_log_flag(self):
+        self.wait_log_flag = False
\ No newline at end of file
