@@ -18,7 +18,7 @@ from adam.log import Log
 from adam.repl_commands import ReplCommands
 from adam.repl_session import ReplSession
 from adam.repl_state import ReplState
-from adam.utils import deep_merge_dicts, lines_to_tabular, log2
+from adam.utils import deep_merge_dicts, deep_sort_dict, lines_to_tabular, log2
 from adam.apps import Apps
 from . import __version__
 
@@ -70,7 +70,7 @@ def enter_repl(state: ReplState):
             cluster = ss[0]
             state.sts = cluster[0]
             state.namespace = cluster[1]
-            state.wait_log(f'Moving to the only Cassandra cluster: {state.sts}@{state.namespace}...')
+            Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}@{state.namespace}...')
     elif state.device == ReplState.A:
         if app := Config().get('repl.auto-enter-app', 'c3/c3'):
             if app != 'no':
@@ -78,9 +78,9 @@ def enter_repl(state: ReplState):
                 state.app_env = ea[0]
                 if len(ea) > 1:
                     state.app_app = ea[1]
-                    state.wait_log(f'Moving to {state.app_env}/{state.app_app}...')
+                    Config().wait_log(f'Moving to {state.app_env}/{state.app_app}...')
                 else:
-                    state.wait_log(f'Moving to {state.app_env}...')
+                    Config().wait_log(f'Moving to {state.app_env}...')
 
     kb = KeyBindings()
 
@@ -102,9 +102,9 @@ def enter_repl(state: ReplState):
                 for cmd in sorted_cmds:
                     s1 = time.time()
                     try:
-                        completions = deep_merge_dicts(completions, cmd.completion(state))
+                        completions = deep_sort_dict(deep_merge_dicts(completions, cmd.completion(state)))
                     finally:
-                        if Config().get('debug.timings', False):
+                        if Config().get('debugs.timings', False):
                             Config().debug('Timing completion calc', cmd.command(), f'{time.time() - s1:.2f}')
 
                 completer = NestedCompleter.from_nested_dict(completions)
@@ -145,14 +145,14 @@ def enter_repl(state: ReplState):
         except EOFError:  # Handle Ctrl+D (EOF) for graceful exit
             break
         except Exception as e:
-            if Config().get('debug.exit-on-error', False):
+            if Config().get('debugs.exit-on-error', False):
                 raise e
             else:
                 log2(e)
                 Config().debug(traceback.format_exc())
         finally:
-            state.clear_wait_log_flag()
-            if Config().get('debug.timings', False) and 'cmd' in locals() and 's0' in locals():
+            Config().clear_wait_log_flag()
+            if Config().get('debugs.timings', False) and 'cmd' in locals() and 's0' in locals():
                 print('Timing command', cmd, f'{time.time() - s0:.2f}')
 
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterCommandHelper, help="Enter interactive shell.")
@@ -168,5 +168,5 @@ def repl(kubeconfig: str, config: str, param: list[str], cluster:str, namespace:
         return
 
     state = ReplState(device=Config().get('repl.start-drive', 'a'), ns_sts=cluster, namespace=namespace, in_repl=True)
-    state, _ = state.apply_args(extra_args)
+    state, _ = state.apply_device_arg(extra_args)
     enter_repl(state)
\ No newline at end of file
