@@ -67,7 +67,7 @@ class ReplState:
         self.in_repl = in_repl
         self.bash_session = bash_session
         self.remote_dir = remote_dir
-        self.wait_log_flag = False
+        # self.wait_log_flag = False
 
         if ns_sts:
             nn = ns_sts.split('@')
@@ -120,6 +120,26 @@ class ReplState:
 
         return (state, new_args)
 
+    def apply_device_arg(self, args: list[str], cmd: list[str] = None) -> tuple['ReplState', list[str]]:
+        state = self
+
+        new_args = []
+        for index, arg in enumerate(args):
+            if index < 6:
+                state = copy.copy(state)
+
+                if arg in [f'{ReplState.A}:', f'{ReplState.C}:', f'{ReplState.P}:']:
+                    state.device = arg.strip(':')
+                else:
+                    new_args.append(arg)
+            else:
+                new_args.append(arg)
+
+        if cmd:
+            new_args = new_args[len(cmd):]
+
+        return (state, new_args)
+
     def validate(self, required: RequiredState = None, pg_required: RequiredState = None, app_required: RequiredState = None):
         if not pg_required and not app_required:
             if required == RequiredState.CLUSTER:
@@ -200,12 +220,4 @@ class ReplState:
         if self.bash_session and self.bash_session.device:
             self.device = self.bash_session.device
 
-        self.bash_session = None
-
-    def wait_log(self, msg: str):
-        if not self.wait_log_flag:
-            log2(msg)
-            self.wait_log_flag = True
-
-    def clear_wait_log_flag(self):
-        self.wait_log_flag = False
\ No newline at end of file
+        self.bash_session = None
\ No newline at end of file
